@@ -16,7 +16,7 @@ print.summary.maxLik <- function( x, ... ) {
    cat("--------------------------------------------\n")
 }
 
-summary.maxLik <- function( object, ... ) {
+summary.maxLik <- function(object, eigentol=1e-12,... ) {
    ## object      object of class "maxLik"
    ## 
    ## RESULTS:
@@ -37,28 +37,31 @@ summary.maxLik <- function( object, ... ) {
       activePar <- rep(TRUE, nParam)
    }
    if(object$code < 100) {
-      if(min(abs(eigen(hessian(object)[activePar,activePar],
-                       symmetric=TRUE, only.values=TRUE)$values)) > 1e-6) {
-         varcovar <- matrix(0, nParam, nParam)
-         varcovar[activePar,activePar] <-
-             solve(-hessian(object)[activePar,activePar])
-         hdiag <- diag(varcovar)
-         if(any(hdiag < 0)) {
-            warning("Diagonal of variance-covariance matrix not positive!\n")
-         }
-         stdd <- sqrt(hdiag)
-         t <- coef/stdd
-         p <- 2*pnorm( -abs( t))
-      } else {
-         stdd <- 0
-         t <- 0
-         p <- 0
-      }
-      results <- cbind("Estimate"=coef, "Std. error"=stdd, "t value"=t, "Pr(> t)"=p)
-      Hess <- NULL
+     hess <- hessian(object)[activePar, activePar] 
+     hessev <- abs(eigen(hess, symmetric=TRUE, only.values=TRUE)$values)
+     if(min(hessev) > (eigentol*max(hessev))){      
+#    if(min(abs(eigen(hessian(object)[activePar,activePar],
+#             symmetric=TRUE, only.values=TRUE)$values)) > eigentol) {
+       varcovar <- matrix(0, nParam, nParam)
+       varcovar[activePar,activePar] <-
+         solve(-hessian(object)[activePar,activePar])
+       hdiag <- diag(varcovar)
+       if(any(hdiag < 0)) {
+         warning("Diagonal of variance-covariance matrix not positive!\n")
+       }
+       stdd <- sqrt(hdiag)
+       t <- coef/stdd
+       p <- 2*pnorm( -abs( t))
+     } else {
+       stdd <- 0
+       t <- 0
+       p <- 0
+     }
+     results <- cbind("Estimate"=coef, "Std. error"=stdd, "t value"=t, "Pr(> t)"=p)
+     Hess <- NULL
    } else {
-      results <- NULL
-      Hess <- NULL
+     results <- NULL
+     Hess <- NULL
    }
    summary <- list(type=object$type,
                    iterations=object$iterations,
